@@ -16,13 +16,15 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include <qstring.h>
 #include <qregexp.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
+//Added by qt3to4:
+#include <QPixmap>
 
 #include <klineedit.h>
 #include <kmessagebox.h>
@@ -31,15 +33,22 @@
 #include <kiconloader.h>
 #include <kglobal.h>
 
-#include "gaduregisteraccountui.h"
+#include "ui_gaduregisteraccountui.h"
 #include "gaduregisteraccount.h"
 #include "gaducommands.h"
 
-GaduRegisterAccount::GaduRegisterAccount( QWidget* parent, const char* name )
-: KDialogBase( parent, name, true, i18n( "Register New Account" ), KDialogBase::User1 | KDialogBase::Ok, KDialogBase::User1, true )
+GaduRegisterAccount::GaduRegisterAccount( QWidget* parent )
+: KDialog( parent )
 {
-	ui = new GaduRegisterAccountUI( this );
-	setMainWidget( ui );
+	setCaption( i18n( "Register New Account" ) );
+	setButtons( KDialog::User1 | KDialog::Ok );
+	setDefaultButton( KDialog::User1 );
+	showButtonSeparator( true );
+
+	QWidget* w = new QWidget( this );
+	ui = new Ui::GaduRegisterAccountUI;
+	ui->setupUi( w );
+	setMainWidget( w );
 
 	ui->valueVerificationSequence->setDisabled( true );
 	setButtonText( User1, i18n( "&Register" ) );
@@ -49,20 +58,20 @@ GaduRegisterAccount::GaduRegisterAccount( QWidget* parent, const char* name )
 	cRegister = new RegisterCommand( this );
 
 	emailRegexp = new QRegExp(  "[\\w\\d.+_-]{1,}@[\\w\\d.-]{1,}" );
-	hintPixmap = KGlobal::iconLoader()->loadIcon ( "gadu_protocol", KIcon::Small );
+	hintPixmap = KIconLoader::global()->loadIcon ( "gadu_protocol", KIconLoader::Small );
 
-	connect( this, SIGNAL( user1Clicked() ), SLOT( doRegister() ) );
-	connect( this, SIGNAL( okClicked() ), SLOT( slotClose() ) );
+	connect( this, SIGNAL(user1Clicked()), SLOT(doRegister()) );
+	connect( this, SIGNAL(okClicked()), SLOT(slotClose()) );
 
-	connect( ui->valueEmailAddress, SIGNAL( textChanged( const QString &) ), SLOT( inputChanged( const QString & ) ) );
-	connect( ui->valuePassword, SIGNAL( textChanged( const QString & ) ), SLOT( inputChanged( const QString & ) ) );
-	connect( ui->valuePasswordVerify, SIGNAL( textChanged( const QString & ) ), SLOT( inputChanged( const QString & ) ) );
-	connect( ui->valueVerificationSequence, SIGNAL( textChanged( const QString & ) ), SLOT( inputChanged( const QString & ) ) );
+	connect( ui->valueEmailAddress, SIGNAL(textChanged(QString)), SLOT(inputChanged(QString)) );
+	connect( ui->valuePassword, SIGNAL(textChanged(QString)), SLOT(inputChanged(QString)) );
+	connect( ui->valuePasswordVerify, SIGNAL(textChanged(QString)), SLOT(inputChanged(QString)) );
+	connect( ui->valueVerificationSequence, SIGNAL(textChanged(QString)), SLOT(inputChanged(QString)) );
 
-	connect( cRegister, SIGNAL( tokenRecieved( QPixmap, QString ) ), SLOT( displayToken( QPixmap, QString ) ) );
-	connect( cRegister, SIGNAL( done(  const QString&,  const QString& ) ), SLOT( registrationDone(  const QString&,  const QString& ) ) );
-	connect( cRegister, SIGNAL( error(  const QString&,  const QString& ) ), SLOT( registrationError(  const QString&,  const QString& ) ) );
-	connect( cRegister, SIGNAL( operationStatus( const QString ) ), SLOT( updateStatus( const QString ) ) );
+	connect( cRegister, SIGNAL(tokenRecieved(QPixmap,QString)), SLOT(displayToken(QPixmap,QString)) );
+	connect( cRegister, SIGNAL(done(QString,QString)), SLOT(registrationDone(QString,QString)) );
+	connect( cRegister, SIGNAL(error(QString,QString)), SLOT(registrationError(QString,QString)) );
+	connect( cRegister, SIGNAL(operationStatus(QString)), SLOT(updateStatus(QString)) );
 
 	updateStatus( i18n( "Retrieving token" ) );
 	cRegister->requestToken();
@@ -131,7 +140,7 @@ GaduRegisterAccount::validateInput()
 	if ( valid )
 	{
 		// clear status message if we have valid data
-		updateStatus( i18n( "" ) );
+		updateStatus( QString( ) );
 	}
 
 	enableButton( User1, valid );
@@ -156,7 +165,7 @@ GaduRegisterAccount::registrationDone(  const QString& /*title*/,  const QString
 	ui->labelVerificationSequence->setDisabled( true );
 	ui->labelInstructions->setDisabled( true );
 	emit registeredNumber( cRegister->newUin(), ui->valuePassword->text() );
-	updateStatus( i18n( "Account created; your new UIN is %1." ).arg(QString::number( cRegister->newUin() )  ) );
+	updateStatus( i18n( "Account created; your new UIN is %1." , cRegister->newUin() ) );
 	enableButton( User1, false );
 	setButtonText( Ok, i18n( "&Close" ) );
 }
@@ -164,13 +173,13 @@ GaduRegisterAccount::registrationDone(  const QString& /*title*/,  const QString
 void
 GaduRegisterAccount::registrationError(  const QString& title,  const QString& what )
 {
-	updateStatus( i18n( "Registration failed: %1" ).arg( what ) );
-	KMessageBox::sorry( this, "Registration was unsucessful, please try again.", title );
+	updateStatus( i18n( "Registration failed: %1", what ) );
+	KMessageBox::sorry( this, i18n("Registration was unsucessful, please try again."), title );
 
-	disconnect( this, SLOT( displayToken( QPixmap, QString ) ) );
-	disconnect( this, SLOT( registrationDone(  const QString&,  const QString& ) ) );
-	disconnect( this, SLOT( registrationError(  const QString&,  const QString& ) ) );
-	disconnect( this, SLOT( updateStatus( const QString ) ) );
+	disconnect( this, SLOT(displayToken(QPixmap,QString)) );
+	disconnect( this, SLOT(registrationDone(QString,QString)) );
+	disconnect( this, SLOT(registrationError(QString,QString)) );
+	disconnect( this, SLOT(updateStatus(QString)) );
 
 	ui->valueVerificationSequence->setDisabled( true );
 	ui->valueVerificationSequence->setText( "" );
@@ -180,7 +189,6 @@ GaduRegisterAccount::registrationError(  const QString& title,  const QString& w
 	// emit UIN 0, to enable 'register new account' button again in dialog below
 	emit registeredNumber( 0, QString( "" ) );
 
-	slotClose();
 	deleteLater();
 }
 
@@ -195,21 +203,20 @@ GaduRegisterAccount::displayToken( QPixmap image, QString /*tokenId */ )
 void
 GaduRegisterAccount::updateStatus( const QString status )
 {
-	ui->labelStatusMessage->setAlignment( AlignCenter );
+	ui->labelStatusMessage->setAlignment( Qt::AlignCenter );
 	ui->labelStatusMessage->setText( status );
 }
 
 void
 GaduRegisterAccount::slotClose()
 {
-	delete cRegister;
-	cRegister = NULL;
+	deleteLater();
 }
 
 GaduRegisterAccount::~GaduRegisterAccount( )
 {
-	kdDebug( 14100 ) << " register Cancel " << endl;
-	delete cRegister;
+	kDebug( 14100 ) << " register Cancel ";
+	delete ui;
 }
 
 #include "gaduregisteraccount.moc"
