@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: general.cpp 901916 2008-12-26 22:13:59Z finex $
+ * $Id: general.cpp 1243993 2011-07-30 12:19:38Z mlaurent $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -680,14 +680,14 @@ GraphSetup::GraphSetup(QWidget *parent) :
   tl->addStretch();
 
   connect(enable_check, SIGNAL(toggled(bool)), this, SLOT(enableToggled(bool)));
-  connect(bg_color, SIGNAL(changed(const QColor &)),
-	  SLOT(colorChanged(const QColor&)));
-  connect(text_color, SIGNAL(changed(const QColor &)),
-	  SLOT(colorChanged(const QColor&)));
-  connect(in_color, SIGNAL(changed(const QColor &)),
-	  SLOT(colorChanged(const QColor&)));
-  connect(out_color, SIGNAL(changed(const QColor &)),
-	  SLOT(colorChanged(const QColor&)));
+  connect(bg_color, SIGNAL(changed(QColor)),
+	  SLOT(colorChanged(QColor)));
+  connect(text_color, SIGNAL(changed(QColor)),
+	  SLOT(colorChanged(QColor)));
+  connect(in_color, SIGNAL(changed(QColor)),
+	  SLOT(colorChanged(QColor)));
+  connect(out_color, SIGNAL(changed(QColor)),
+	  SLOT(colorChanged(QColor)));
 
   tl->activate();
 
